==> flink-1.18.1-src.tgz: flink-1.18.1/flink-runtime-web/web-dashboard/src/app/components/humanize-watermark.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Pipe, PipeTransform } from '@angular/core';

import { ConfigService } from '@flink-runtime-web/services';

@Pipe({
  name: 'humanizeWatermark',
  standalone: true
})
export class HumanizeWatermarkPipe implements PipeTransform {
  constructor(private readonly configService: ConfigService) {}

  public transform(value: number): number | string {
    if (isNaN(value) || value <= this.configService.LONG_MIN_VALUE) {
      return 'No Watermark (Watermarks are only available if EventTime is used)';
    } else {
      return value;
    }
  }
}

@Pipe({
  name: 'humanizeWatermarkToDatetime',
  standalone: true
})
export class HumanizeWatermarkToDatetimePipe implements PipeTransform {
  constructor(private readonly configService: ConfigService) {}

  public transform(value: number): number | string {
    if (isNaN(value) || value <= this.configService.LONG_MIN_VALUE) {
      return '-';
    } else {
      return new Date(value).toLocaleString();
    }
  }
}

==> flink-2.1.1-src.tgz: flink-2.1.1/flink-runtime-web/web-dashboard/src/app/components/humanize-watermark.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { Pipe, PipeTransform } from '@angular/core';

import { ConfigService } from '@flink-runtime-web/services';

@Pipe({
  name: 'humanizeWatermark',
  standalone: true
})
export class HumanizeWatermarkPipe implements PipeTransform {
  constructor(private readonly configService: ConfigService) {}

  public transform(value: number): number | string {
    if (isNaN(value) || value <= this.configService.LONG_MIN_VALUE) {
      return 'No Watermark (Watermarks are only available if EventTime is used)';
    } else {
      return value;
    }
  }
}

@Pipe({
  name: 'humanizeWatermarkToDatetime',
  standalone: true
})
export class HumanizeWatermarkToDatetimePipe implements PipeTransform {
  constructor(private readonly configService: ConfigService) {}

  public transform(value: number): number | string {
    if (value == null || isNaN(value) || value <= this.configService.LONG_MIN_VALUE) {
      return 'N/A';
    } else {
      return new Date(value).toLocaleString();
    }
  }
}
